import time
from random import random

from darcyai_engine.perceptor.perceptor import Perceptor
from darcyai_engine.config import Config


class PerceptorMock(Perceptor):
    """
    Mock perceptor that generates random data.

    Args:
        mock (Mock): Mock object to be used for testing.
        sleep (float): Sleep time in seconds.
    """
    def __init__(self, sleep=None, mock=None, **kwargs):
        super().__init__(**kwargs)

        self.config_schema = [
            Config("config_1", "str", "", "Config 1"),
            Config("config_2", "int", 0, "Config 2"),
            Config("config_3", "bool", False, "Config 3"),
        ]

        self.event_names = ["event_1", "event_2"]

        if sleep is not None:
            self.__sleep = sleep
        else:
            self.__sleep = int(random() * 4) + 1

        self.__mock = mock

    def run(self, input_data, config):
        if self.__mock is not None:
            self.__mock.run(input_data)

        time.sleep(self.__sleep)

        return "Hello!!!"

    def load(self, accelerator_idx=None):
        if self.__mock is not None:
            self.__mock.load(accelerator_idx=None)

        super().set_loaded(True)

    def get_event_names(self):
        return ["event_1", "event_2"]
